@@ -1,48 +1,21 @@
-/*
- * T.C.F.S. 2.0 Alpha 1 
- *
- *      	   This  program  handles  RPC  "NFS"  data  requests
- *              adopting a secure transfer protocol.
- *                 This   is  an  unsecure   and  unchecked  version,
- *              use at your own risk.
- *
- *              Please, report Bugs to: <tcfs@edu-gw.dia.unisa.it>
- *
- * Authors:	Giuseppe Cattaneo, <cattaneo@udsab.dia.unisa.it>
- *		Giuseppe Persiano, <giuper@udsab.dia.unisa.it>
- *		Andrea Cozzolino, <andcoz@edu-gw.dia.unisa.it>
- *		Angelo Celentano, <angcel@edu-gw.dia.unisa.it>
- *		Aniello Del Sorbo, <anidel@edu-gw.dia.unisa.it>
- *		Ermelindo Mauriello, <ermmau@edu-gw.dia.unisa.it>
- *		Raffaele Pisapia, <rafpis@edu-gw.dia.unisa.it>
- *
- *   Permission to  use, copy, and modify  this software  without fee
- * is hereby granted, provided that this entire notice is included in
- * all copies  of  any  software  which  is  or  includes a  copy  or
- * modification of this software and in all copies  of the supporting
- * documentation for such software.
- *
- *   This  software is  distribuited  under  the  GNU General  Public
- * License  (version  2, June  1991). Check  the  file  'COPYING'  for
- * more  infos. Some  parts of  this  software  derive  from the  NFS
- * implementation in the Linux kernel 2.0.x.
- *
- * This software  maybe be used  for any  purpose provided  the above
- * copyright  notice  is retained.  It  is  supplied  as is,  with no
- * warranty expressed or implied.
- *
- */
-
-/* -+-_== */
-
 /* Copyright (C) 1992 Eric Young - see COPYING for more details */
 /* Collected and modified by Werner Almesberger */
 
-#include <linux/autoconf.h>
-
-#ifdef TCFS_DES
-
 #include <linux/kdes.h>
+#include <linux/kdes.h>
+#include <linux/sched.h>
+#include <linux/kernel.h>
+#include <linux/errno.h>
+#include <linux/fcntl.h>
+#include <linux/stat.h>
+#include <linux/mm.h>
+#include <linux/tcfs_fs.h>
+#include <linux/malloc.h>
+#include <linux/pagemap.h>
+
+#include <asm/segment.h>
+#include <asm/system.h>
+
 
 
 /* from des.h */
@@ -435,8 +408,9 @@ static char shifts2[16]={0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,0};
 	how to use xors :-) I got it to its final state.
 	*/
 
-static void des_encrypt(unsigned long *input,unsigned long *output,
-    des_key_schedule ks,int encrypt)
+static void 
+single_des_encrypt(unsigned long *input,unsigned long *output,
+		 des_key_schedule ks,int encrypt)
 	{
 	register unsigned long l,r,t,u;
 #ifdef ALT_ECB
@@ -511,13 +485,103 @@ static void des_encrypt(unsigned long *input,unsigned long *output,
 	output[1]=r;
 	}
 
-int des_ecb_encrypt(des_cblock *input,des_cblock *output,des_key_schedule ks,
-    int encrypt)
+static void 
+des_encrypt(unsigned long *input,unsigned long *output,des_key_schedule *ks,int encrypt)
+{
+
+
+	unsigned long temp1[2];
+	unsigned long temp2[2];
+
+#ifdef TCFS_DEBUG
+	printk("TCFS_debug: in des_encrypt\n");
+#endif
+
+#ifdef TCFS_DEBUG
+        {       
+                int i;  
+                char *pnt;
+    
+                printk("TCFS_debug: calling single_des_encrypt\n");
+		printk("TCFS_debug: with key: ");
+    
+                pnt=(char *)ks;
+                for(i=0;i<16;i++,pnt++){
+                        printk("%x:",(unsigned int)*pnt);
+                }       
+   		printk("\n"); 
+	}
+#endif
+
+	single_des_encrypt(input,temp1,*ks,encrypt);
+
+#ifdef TCFS_DEBUG
+        {       
+                int i;  
+                char *pnt;
+    
+                printk("TCFS_debug: calling single_des_encrypt\n");
+		printk("TCFS_debug: with key: ");
+    
+                pnt=(char *)&ks[1];
+                for(i=0;i<16;i++,pnt++){
+                        printk("%x:",(unsigned int)*pnt);
+                }       
+   		printk("\n"); 
+	}
+#endif
+
+	single_des_encrypt(temp1,temp2,*(ks+1),1-encrypt);
+
+#ifdef TCFS_DEBUG
+        {       
+                int i;  
+                char *pnt;
+    
+                printk("TCFS_debug: calling single_des_encrypt\n");
+		printk("TCFS_debug: with key: ");
+    
+                pnt=(char *)ks;
+                for(i=0;i<16;i++,pnt++){
+                        printk("%x:",(unsigned int)*pnt);
+                }       
+   		printk("\n"); 
+	}
+#endif
+
+	single_des_encrypt(temp2,output,*ks,encrypt);
+
+#ifdef TCFS_DEBUG
+	printk ("TCFS_debug: exiting des_encrypt\n");
+#endif
+}
+
+int 
+des_ecb_encrypt(des_cblock *input,des_cblock *output,des_key_schedule *ks, int encrypt)
 	{
 	register unsigned long l0,l1;
 	register unsigned char *in,*out;
 	unsigned long ll[2];
 
+
+/*
+#ifdef TCFS_DEBUG
+	     {       
+                int i;  
+                char *pnt;
+     
+		printk("TCFS_debug: in des_ecb_encrypt\n");
+                printk("TCDS_debug: input key: ");
+     
+                pnt=(char *)&ks[0];
+                for(i=0;i<16;i++,pnt++){
+                        printk("%x:",(unsigned int)*pnt);
+                }
+    		printk("\n"); 
+        }
+#endif
+*/
+
 	in=(unsigned char *)input;
 	out=(unsigned char *)output;
 	c2l(in,l0);
@@ -530,11 +594,18 @@ int des_ecb_encrypt(des_cblock *input,des_cblock *output,des_key_schedule ks,
 	l2c(l0,out);
 	l2c(l1,out);
 	return(0);
-	}
+
+/*
+#ifdef TCFS_DEBUG
+	printk("TCFS_debug: exiting des_ecb_encrypt\n");
+#endif
+*/
+}
 
 /* from set_key.c */
 
-void des_set_key(des_cblock *key,des_key_schedule schedule)
+void 
+des_set_key(des_cblock *key,des_key_schedule schedule)
 	{
 	register unsigned long c,d,t,s;
 	register unsigned char *in;
@@ -588,5 +659,3 @@ void des_set_key(des_cblock *key,des_key_schedule schedule)
 		*(k++)=s&0xffffffff;
 		}
 	}
-
-#endif
