@@ -24,7 +24,7 @@ struct login
 {
 	int len;
 	uid_t uid;
-	unsigned char deskey[20];
+	unsigned char deskey[KEYSIZE];
 };
 
 struct tgroup
@@ -33,7 +33,7 @@ struct tgroup
 	uid_t uid;
 	int n;
 	int soglia;
-	unsigned char deskey[32];
+	unsigned char deskey[KEYSIZE+KEYSIZE/8];
 };
 
 /* User Key Ioctls */
@@ -62,7 +62,7 @@ struct tgroup
 
 struct hash_entry {
 	unsigned int uid;
-	unsigned char deskey[20];
+	unsigned char deskey[KEYSIZE];
 	des_key_schedule *ks;
 	unsigned int count;
 	unsigned char permanent;
@@ -71,7 +71,7 @@ struct hash_entry {
 
 struct gid_hash_entry {
 	unsigned int gid;
-	unsigned char gidkey[20];
+	unsigned char gidkey[KEYSIZE+KEYSIZE/8];
 	des_key_schedule *ks;
 	unsigned int ins;
 	struct hash_entry * key;
